export function mergeDeep(...sources) {
    const isObject = (val) => val !== null && typeof val === "object" && !Array.isArray(val);
    return sources.reduce((acc, source) => {
        if (Array.isArray(acc) && Array.isArray(source)) {
            const maxLength = Math.max(acc.length, source.length);
            const result = [];
            for (let i = 0; i < maxLength; i++) {
                const a = acc[i];
                const b = source[i];
                if (isObject(a) && isObject(b)) {
                    result[i] = mergeDeep(a, b);
                }
                else {
                    result[i] = b ?? a;
                }
            }
            return result;
        }
        if (isObject(acc) && isObject(source)) {
            const result = { ...acc };
            for (const [key, val] of Object.entries(source)) {
                const aVal = acc[key];
                if (isObject(aVal) && isObject(val)) {
                    result[key] = mergeDeep(aVal, val);
                }
                else {
                    result[key] = val;
                }
            }
            return result;
        }
        return source;
    });
}
export function hexToRgb(hex) {
    const result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
    return `${Number.parseInt(result[1], 16)}, ${Number.parseInt(result[2], 16)}, ${Number.parseInt(result[3], 16)}`;
}
